package sun.security.x509;

import sun.security.util.DerOutputStream;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.Collections;
import sun.security.util.DerValue;
import java.io.IOException;
import java.util.LinkedHashSet;
import java.security.cert.PolicyQualifierInfo;
import java.util.Set;

public class PolicyInformation
{
    public static final String NAME = "PolicyInformation";
    public static final String ID = "id";
    public static final String QUALIFIERS = "qualifiers";
    private CertificatePolicyId policyIdentifier;
    private Set<PolicyQualifierInfo> policyQualifiers;
    
    public PolicyInformation(CertificatePolicyId policyIdentifier, Set<PolicyQualifierInfo> c) throws IOException {
        if (c == null) {
            throw new NullPointerException("policyQualifiers is null");
        }
        this.policyQualifiers = new LinkedHashSet(c);
        this.policyIdentifier = policyIdentifier;
        return;
    }
    
    public PolicyInformation(DerValue derValue) throws IOException {
        if (derValue.tag != 48) {
            throw new IOException("Invalid encoding of PolicyInformation");
        }
        this.policyIdentifier = new CertificatePolicyId(derValue.data.getDerValue());
        if (derValue.data.available() != 0) {
            this.policyQualifiers = new LinkedHashSet();
            DerValue derValue2 = derValue.data.getDerValue();
            if (derValue2.tag != 48) {
                throw new IOException("Invalid encoding of PolicyInformation");
            }
            if (derValue2.data.available() == 0) {
                throw new IOException("No data available in policyQualifiers");
            }
            while (derValue2.data.available() != 0) {
                this.policyQualifiers.add(new PolicyQualifierInfo(derValue2.data.getDerValue().toByteArray()));
            }
        }
        else {
            this.policyQualifiers = Collections.emptySet();
        }
        return;
    }
    
    @Override
    public boolean equals(Object o) {
        if (!(o instanceof PolicyInformation)) {
            return false;
        }
        PolicyInformation policyInformation = (PolicyInformation)o;
        return this.policyIdentifier.equals(policyInformation.getPolicyIdentifier()) && this.policyQualifiers.equals(policyInformation.getPolicyQualifiers());
    }
    
    @Override
    public int hashCode() {
        return 37 * (37 + this.policyIdentifier.hashCode()) + this.policyQualifiers.hashCode();
    }
    
    public CertificatePolicyId getPolicyIdentifier() {
        return this.policyIdentifier;
    }
    
    public Set<PolicyQualifierInfo> getPolicyQualifiers() {
        return this.policyQualifiers;
    }
    
    public Object get(String str) throws IOException {
        if (str.equalsIgnoreCase("id")) {
            return this.policyIdentifier;
        }
        if (str.equalsIgnoreCase("qualifiers")) {
            return this.policyQualifiers;
        }
        throw new IOException("Attribute name [" + str + "] not recognized by PolicyInformation.");
    }
    
    public void set(String str, Object o) throws IOException {
        if (str.equalsIgnoreCase("id")) {
            if ((o instanceof CertificatePolicyId)) {
                this.policyIdentifier = (CertificatePolicyId)o;
            }
            else {
                throw new IOException("Attribute value must be instance of CertificatePolicyId.");
            }
        }
        else if (str.equalsIgnoreCase("qualifiers")) {
            if (this.policyIdentifier == null) {
                throw new IOException("Attribute must have a CertificatePolicyIdentifier value before PolicyQualifierInfo can be set.");
            }
            if ((o instanceof Set)) {
                Iterator<Object> iterator = ((Set)o).iterator();
                while (iterator.hasNext()) {
                    if (!(iterator.next() instanceof PolicyQualifierInfo)) {
                        throw new IOException("Attribute value must be aSet of PolicyQualifierInfo objects.");
                    }
                    continue;
                }
                this.policyQualifiers = (Set)o;
            }
            else {
                throw new IOException("Attribute value must be of type Set.");
            }
        }
        else {
            throw new IOException("Attribute name [" + str + "] not recognized by PolicyInformation");
        }
    }
    
    public void delete(String str) throws IOException {
        if (str.equalsIgnoreCase("qualifiers")) {
            this.policyQualifiers = Collections.emptySet();
            return;
        }
        if (str.equalsIgnoreCase("id")) {
            throw new IOException("Attribute ID may not be deleted from PolicyInformation.");
        }
        throw new IOException("Attribute name [" + str + "] not recognized by PolicyInformation.");
    }
    
    public Enumeration<String> getElements() {
        AttributeNameEnumeration attributeNameEnumeration = new AttributeNameEnumeration();
        attributeNameEnumeration.addElement("id");
        attributeNameEnumeration.addElement("qualifiers");
        return attributeNameEnumeration.elements();
    }
    
    public String getName() {
        return "PolicyInformation";
    }
    
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder("  [" + this.policyIdentifier.toString());
        sb.append(this.policyQualifiers + "  ]\n");
        return sb.toString();
    }
    
    public void encode(DerOutputStream derOutputStream) throws IOException {
        DerOutputStream derOutputStream2 = new DerOutputStream();
        this.policyIdentifier.encode(derOutputStream2);
        if (!this.policyQualifiers.isEmpty()) {
            DerOutputStream derOutputStream3 = new DerOutputStream();
            Iterator<PolicyQualifierInfo> iterator = this.policyQualifiers.iterator();
            while (iterator.hasNext()) {
                derOutputStream3.write(((PolicyQualifierInfo)iterator.next()).getEncoded());
            }
            derOutputStream2.write((byte)48, derOutputStream3);
        }
        derOutputStream.write((byte)48, derOutputStream2);
    }
}
